@@ -13,9 +13,21 @@ __all__ = ["ddb_to_event"]
 deserialize = TypeDeserializer().deserialize
 
 VALID_EVENT_TYPE = {
+    #Inventory
+    "InventoryCreateRequest" : "InventoryCreateRequest" ,
     "InventoryUpdateRequest" :  "InventoryUpdateRequest",
-    "RequisitionItemReleaseEvent":"RequisitionItemReleaseEvent"
+    "InventoryUpdateResponse" : "InventoryUpdateResponse",
+    "RequisitionItemRequest" : "RequisitionItemRequest",
+    "RequisitionItemRelease":"RequisitionItemRelease",
+    "RequisitionStatusUpdate" : "RequisitionStatusUpdate",
+    "ValidateInventoryItemRequest" : "ValidateInventoryItemRequest",
+    "ValidateInventoryItemResponse":"ValidateInventoryItemResponse",
+    "GetInventoryRequest":"GetInventoryRequest",
+    "GetInventoryResponse" : "GetInventoryResponse",
 
+    #Products
+    "GetProductRequest" : "GetProductRequest" ,
+    "GetProductResponse" : "GetProductResponse"
 }
 
 
